using System;
using System.Data;
using System.Data.OleDb;

namespace AlertLib
{
	public class AlertManager
	{
		/// <summary>
		/// Default constructor is made private so that
		/// nobody create an instance of it.. all our methods
		/// are 'static' and can be called 'AlertManager.MethodName()'.
		/// So, there is no need to create an instance.
		/// </summary>
		private AlertManager()
		{
		}

		/// <summary>
		/// This method retrieves all the alerts from the database.
		/// </summary>
		/// <returns></returns>
		public static DataSet GetAlerts ()
		{
			string connectionString = System.Configuration.ConfigurationSettings.AppSettings["AlertsDsn"];
			OleDbConnection myConnection = new OleDbConnection( connectionString );

			string query = "select * from ALERT where status = 1 order by AlertId";

			OleDbDataAdapter myAdapter = new OleDbDataAdapter( query, myConnection );
			DataSet alerts = new DataSet();
			myAdapter.Fill(alerts, "Alerts");

			return alerts;
		}

		/// <summary>
		/// This method retrieves all the alerts from the database based
		/// on alert time.
		/// </summary>
		/// <returns></returns>
		public static DataSet GetAlerts (DateTime alertTime)
		{
			string connectionString = System.Configuration.ConfigurationSettings.AppSettings["AlertsDsn"];
			OleDbConnection myConnection = new OleDbConnection( connectionString );

			string query = "select * from ALERT where AlertTime >= #" + alertTime + "#  order by AlertId";

			OleDbDataAdapter myAdapter = new OleDbDataAdapter(query, myConnection);
			DataSet alerts = new DataSet();
			myAdapter.Fill(alerts, "Alerts");

			return alerts;
		}

		public static void CreateAlert( Alert AlertObj )
		{
			string connectionString = System.Configuration.ConfigurationSettings.AppSettings["AlertsDsn"];
			OleDbConnection myConnection = new OleDbConnection( connectionString );
			myConnection.Open();

			string query = "insert into ALERT ( Title, Message, Url, AlertTime, Priority, OtherData, Status ) values ( '" + AlertObj.Title + "', '" + AlertObj.Message + "', '" + AlertObj.Url + "', '" + AlertObj.AlertTime + "', " + (int)AlertObj.Priority + ", '" + AlertObj.OtherData + "', " + AlertObj.Status + " ) ";

			OleDbCommand myCommand = new OleDbCommand( query, myConnection );
			myCommand.ExecuteNonQuery();
			myConnection.Close();
		}

		public static void UpdateAlert( Alert AlertObj )
		{
			string connectionString = System.Configuration.ConfigurationSettings.AppSettings["AlertsDsn"];
			OleDbConnection myConnection = new OleDbConnection( connectionString );
			myConnection.Open();

			string query = "update ALERT set Title = '" + AlertObj.Title + "', Message = '" + AlertObj.Message + "', Url = '" + AlertObj.Url + "', AlertTime = '" + AlertObj.AlertTime + "', Priority = " + (int)AlertObj.Priority + ", OtherData = '" + AlertObj.OtherData + "', Status = " + AlertObj.Status + " where AlertId = " + AlertObj.AlertId;

			OleDbCommand myCommand = new OleDbCommand( query, myConnection );
			myCommand.ExecuteNonQuery();
			myConnection.Close();

			bool condition = false;

			if ( condition )
			{
				throw new UserNotExistsException( "There is an error, The user you are trying to update does not exists." );
			}
		}
	}

	public class UserNotExistsException : System.ApplicationException 
	{
		public UserNotExistsException ( string message ) : base ( message )
		{
		}
	}

}